@@ -10,7 +10,7 @@ Dancer::Plugin::Database::Core - Shared core for D1 and D2 Database plugins
 
 =cut
 
-our $VERSION = '0.13';
+our $VERSION = '0.20';
 
 my %handles;
 # Hashref used as key for default handle, so we don't have a magic value that
@@ -328,8 +328,12 @@ sub _get_connection {
 sub _check_connection {
     my $dbh = shift;
     return unless $dbh;
-    if ($dbh->{Active} && (my $result = $dbh->ping)) {
-        if (int($result)) {
+    if ($dbh->{Active}) { 
+        my $result = eval { $dbh->ping };
+
+        return 0 if $@;
+
+	    if (int($result)) {
             # DB driver itself claims all is OK, trust it:
             return 1;
         } else {
@@ -392,7 +396,7 @@ L<http://search.cpan.org/dist/Dancer-Plugin-Database-Core/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2013 David Precious.
+Copyright 2016 David Precious.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the the Artistic License (2.0). You may obtain a
